@@ -201,10 +201,10 @@ OutputModel* KCMKScreen::outputModel() const
 
 void KCMKScreen::identifyOutputs()
 {
-    if (!m_config || !m_config->config() || m_outputIdentifier) {
+    if (!m_config || !m_config->initialConfig() || m_outputIdentifier) {
         return;
     }
-    m_outputIdentifier.reset(new OutputIdentifier(m_config->config(), this));
+    m_outputIdentifier.reset(new OutputIdentifier(m_config->initialConfig(), this));
     connect(m_outputIdentifier.get(), &OutputIdentifier::identifiersFinished,
             this, [this]() {
         m_outputIdentifier.reset();
@@ -374,7 +374,7 @@ void KCMKScreen::writeGlobalScale()
     // Scaling the fonts makes sense if you don't also set a font DPI, but we NEED to set a font
     // DPI for both PlasmaShell which does it's own thing, and for KDE4/GTK2 applications.
     QString screenFactors;
-    for (const KScreen::OutputPtr output : m_config->config()->outputs()) {
+    for (const auto &output: m_config->config()->outputs()) {
         screenFactors.append(output->name() + QLatin1Char('=') + QString::number(m_globalScale) + QLatin1Char(';'));
     }
     config->group("KScreen").writeEntry("ScreenScaleFactors", screenFactors);
