@@ -18,10 +18,12 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <kscreen/config.h>
 
-#include <QTimer>
 #include <QVector>
 
-class QQuickView;
+namespace PlasmaQuick
+{
+    class Dialog;
+}
 
 class OutputIdentifier : public QObject
 {
@@ -38,6 +40,5 @@ protected:
   bool eventFilter(QObject *object, QEvent *event) override;
 
 private:
-    QVector<QQuickView*> m_views;
-    QTimer m_timer;
+    QVector<PlasmaQuick::Dialog*> m_views;
 };
